@@ -16,29 +16,35 @@
 
 #pragma once
 
-#include "branch.hpp"
+#include "branches.hpp"
+#include "category.hpp"
 #include "config_cachefiles.hpp"
+#include "config_follow_symlinks.hpp"
 #include "config_inodecalc.hpp"
+#include "config_link_exdev.hpp"
+#include "config_log_metrics.hpp"
 #include "config_moveonenospc.hpp"
 #include "config_nfsopenhack.hpp"
 #include "config_readdir.hpp"
+#include "config_rename_exdev.hpp"
 #include "config_statfs.hpp"
 #include "config_statfsignore.hpp"
 #include "config_xattr.hpp"
 #include "enum.hpp"
 #include "errno.hpp"
-#include "func_category.hpp"
 #include "funcs.hpp"
 #include "policy.hpp"
-#include "policy_cache.hpp"
+#include "rwlock.hpp"
 #include "tofrom_wrapper.hpp"
 
-#include <fuse.h>
+#include "fuse.h"
 
+#include <cstdint>
+#include <map>
+#include <memory>
 #include <string>
 #include <vector>
 
-#include <stdint.h>
 #include <sys/stat.h>
 
 typedef ToFromWrapper<bool>                 ConfigBOOL;
@@ -47,20 +53,55 @@ typedef ToFromWrapper<int>                  ConfigINT;
 typedef ToFromWrapper<std::string>          ConfigSTR;
 typedef std::map<std::string,ToFromString*> Str2TFStrMap;
 
+extern const std::string CONTROLFILE;
+
 class Config
 {
+public:
+  struct Err
+  {
+    int err;
+    std::string str;
+  };
+
+  typedef std::vector<Err> ErrVec;
+
+public:
+  class Read
+  {
+  public:
+    Read();
+
+  public:
+    inline const Config* operator->() const;
+
+  private:
+    const Config &_cfg;
+  };
+
+public:
+  class Write
+  {
+  public:
+    Write();
+
+  public:
+    Config* operator->();
+
+  private:
+    Config &_cfg;
+  };
+
 public:
   Config();
 
 public:
-  mutable PolicyCache open_cache;
-
-public:
-  const std::string controlfile;
+  Config& operator=(const Config&);
 
 public:
   ConfigBOOL     async_read;
   ConfigBOOL     auto_cache;
+  ConfigUINT64   minfreespace;
   Branches       branches;
   ConfigUINT64   cache_attr;
   ConfigUINT64   cache_entry;
@@ -69,17 +110,19 @@ public:
   ConfigBOOL     cache_readdir;
   ConfigUINT64   cache_statfs;
   ConfigBOOL     cache_symlinks;
-  FuncCategories category;
+  Categories     category;
   ConfigBOOL     direct_io;
   ConfigBOOL     dropcacheonclose;
   ConfigSTR      fsname;
+  FollowSymlinks follow_symlinks;
   Funcs          func;
   ConfigUINT64   fuse_msg_size;
   ConfigBOOL     ignorepponrename;
   InodeCalc      inodecalc;
   ConfigBOOL     kernel_cache;
   ConfigBOOL     link_cow;
-  ConfigUINT64   minfreespace;
+  LinkEXDEV      link_exdev;
+  LogMetrics     log_metrics;
   ConfigSTR      mount;
   MoveOnENOSPC   moveonenospc;
   NFSOpenHack    nfsopenhack;
@@ -88,6 +131,7 @@ public:
   ConfigBOOL     posix_acl;
   ReadDir        readdir;
   ConfigBOOL     readdirplus;
+  RenameEXDEV    rename_exdev;
   ConfigBOOL     security_capability;
   SrcMounts      srcmounts;
   StatFS         statfs;
@@ -112,11 +156,50 @@ public:
   int get(const std::string &key, std::string *val) const;
   int set_raw(const std::string &key, const std::string &val);
   int set(const std::string &key, const std::string &val);
+  int set(const std::string &kv);
 
 public:
-  static const Config &ro(void);
-  static Config       &rw(void);
+  int from_stream(std::istream &istrm, ErrVec *errs);
+  int from_file(const std::string &filepath, ErrVec *errs);
 
 private:
   Str2TFStrMap _map;
+
+private:
+  static Config _singleton;
+
+public:
+  friend class Read;
+  friend class Write;
 };
+
+std::ostream& operator<<(std::ostream &s,const Config::ErrVec &ev);
+
+inline
+Config::Read::Read()
+  : _cfg(Config::_singleton)
+{
+
+}
+
+inline
+const
+Config*
+Config::Read::operator->() const
+{
+  return &_cfg;
+}
+
+inline
+Config::Write::Write()
+  : _cfg(Config::_singleton)
+{
+
+}
+
+inline
+Config*
+Config::Write::operator->()
+{
+  return &_cfg;
+}
