@@ -18,9 +18,11 @@
 
 #pragma once
 
-#include <stdint.h>
+#include <cstdint>
+
 #include <sys/statvfs.h>
 
+
 namespace fs
 {
   uint64_t
