@@ -16,11 +16,12 @@
 
 #pragma once
 
-#include <fuse.h>
+#include "fuse.h"
 
 #include <sys/types.h>
 #include <unistd.h>
 
+
 namespace FUSE
 {
   int
