@@ -16,10 +16,11 @@
 
 #pragma once
 
-#include <fuse.h>
+#include "fuse.h"
 
 #include <sys/types.h>
 
+
 namespace FUSE
 {
   int
@@ -27,4 +28,10 @@ namespace FUSE
            struct fuse_bufvec     **buf,
            size_t                   size,
            off_t                    offset);
+
+  int
+  read_buf_null(const fuse_file_info_t  *ffi,
+                struct fuse_bufvec     **buf,
+                size_t                   size,
+                off_t                    offset);
 }
