@@ -16,9 +16,9 @@
 
 #include "ef.hpp"
 
+#include <cstdint>
 #include <string>
 
-#include <stdint.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
@@ -28,6 +28,7 @@
 #define GB (MB * 1024UL)
 #define TB (GB * 1024UL)
 
+
 namespace num
 {
   int
