@@ -25,11 +25,11 @@
 namespace ugid
 {
   void
-  initgroups(const uid_t uid,
-             const gid_t gid)
+  initgroups(const uid_t uid_,
+             const gid_t gid_)
   {
     static __thread gid_t_cache cache = {0};
 
-    cache.initgroups(uid,gid);
+    cache.initgroups(uid_,gid_);
   }
 }
